@@ -6,5 +6,10 @@ from datup.preparation.data_preparation import (
     col_cast, 
     featureselection_correlation, 
     Error,
-    CorrelationError
+    CorrelationError,
+    remove_chars_metadata,
+    to_lowercase_metadata,
+    profile_dataset,
+    replace_categorical_na,
+    replace_numeric_na
 ) 
\ No newline at end of file
